==> generator-alexa-skill-basic-0.1.0.tgz: package/generators/app/index.js <==
'use strict';
const Generator = require('yeoman-generator');
const chalk = require('chalk');
const yosay = require('yosay');
const _ = require('lodash');

module.exports = class extends Generator {
  // The name `constructor` is important here
  constructor(args, opts) {
    // Calling the super constructor is important so our generator is correctly set up
    super(args, opts);

    // This makes `appname` a required argument.
    // this.argument('appname', { type: String, required: true });
    // And you can then access it later on this way; e.g. CamelCased
    this.appName = _.upperFirst(_.camelCase(this.appname));
    this.appTitle = _.kebabCase(this.appName);

    // Next, add your custom code
    // this.option('babel'); // This method adds support for a `--babel` flag
  }

  prompting() {
    // Have Yeoman greet the user.
    this.log(yosay(
      'Welcome to the funkadelic ' + chalk.red('generator-alexa-skill-basic') + ' generator!'
    ));

    const prompts = [
      // {
      //   type: 'confirm',
      //   name: 'someAnswer',
      //   message: 'Would you like to enable this option?',
      //   default: true
      // }
    ];

    return this.prompt(prompts).then(props => {
      // To access props later use this.props.someAnswer;
      this.props = props;
    });
  }

  writing() {
    this.fs.copy(
      this.templatePath('gitignore'),
      this.destinationPath('.gitignore')
    );
    this.fs.copy(
      this.templatePath('npmignore'),
      this.destinationPath('.npmignore')
    );
    this.fs.copy(
      this.templatePath('tsconfig.json'),
      this.destinationPath('tsconfig.json')
    );
    this.fs.copy(
      this.templatePath('tslint.json'),
      this.destinationPath('tslint.json')
    );

    this.fs.copyTpl(
      this.templatePath('src/index.ts'),
      this.destinationPath('src/index.ts'),
      {
        appName: this.appName,
        appTitle: this.appTitle,
        author: "me"
      }
    );

    this.fs.copyTpl(
      this.templatePath('speech-assets/intent-schema.json'),
      this.destinationPath('speech-assets/intent-schema.json'),
      {
        appName: this.appName,
        appTitle: this.appTitle,
        author: "me"
      }
    );
    this.fs.copyTpl(
      this.templatePath('speech-assets/sample-utterances.txt'),
      this.destinationPath('speech-assets/sample-utterances.txt'),
      {
        appName: this.appName,
        appTitle: this.appTitle,
        author: "me"
      }
    );

    this.fs.copyTpl(
      this.templatePath('package.json'),
      this.destinationPath('package.json'),
      {
        appName: this.appName,
        appTitle: this.appTitle,
        author: "me"
      }
    );
    this.fs.copyTpl(
      this.templatePath('bower.json'),
      this.destinationPath('bower.json'),
      {
        appName: this.appName,
        appTitle: this.appTitle,
        author: "me"
      }
    );
    this.fs.copyTpl(
      this.templatePath('README.md'),
      this.destinationPath('README.md'),
      {
        appName: this.appName,
        appTitle: this.appTitle,
        author: "me"
      }
    );
    this.fs.copyTpl(
      this.templatePath('LICENSE'),
      this.destinationPath('LICENSE'),
      {
        appName: this.appName,
        appTitle: this.appTitle,
        author: "me"
      }
    );
  }

  install() {
    this.installDependencies();

    // this.npmInstall(['restify'], { 'save': true });
  }
};

==> generator-alexa-skill-basic-0.1.3.tgz: package/generators/app/index.js <==
'use strict';
const Generator = require('yeoman-generator');
const chalk = require('chalk');
const yosay = require('yosay');
const _ = require('lodash');

module.exports = class extends Generator {
  // The name `constructor` is important here
  constructor(args, opts) {
    // Calling the super constructor is important so our generator is correctly set up
    super(args, opts);

    // This makes `appname` a required argument.
    // this.argument('appname', { type: String, required: true });
    // And you can then access it later on this way; e.g. CamelCased
    this.appName = _.upperFirst(_.camelCase(this.appname));
    this.appTitle = _.kebabCase(this.appName);
    // tbd: invocation name???

    // Next, add your custom code
    // this.option('babel'); // This method adds support for a `--babel` flag
  }

  prompting() {
    // Have Yeoman greet the user.
    this.log(yosay(
      'Welcome to the funkadelic ' + chalk.red('generator-alexa-skill-basic') + ' generator!'
    ));

    const prompts = [
      // {
      //   type: 'confirm',
      //   name: 'someAnswer',
      //   message: 'Would you like to enable this option?',
      //   default: true
      // }
    ];

    return this.prompt(prompts).then(props => {
      // To access props later use this.props.someAnswer;
      this.props = props;
    });
  }

  writing() {
    this.fs.copy(
      this.templatePath('gitignore'),
      this.destinationPath('.gitignore')
    );
    this.fs.copy(
      this.templatePath('npmignore'),
      this.destinationPath('.npmignore')
    );
    this.fs.copy(
      this.templatePath('tsconfig.json'),
      this.destinationPath('tsconfig.json')
    );
    this.fs.copy(
      this.templatePath('tslint.json'),
      this.destinationPath('tslint.json')
    );

    this.fs.copy(
      this.templatePath('images/logo.svg'),
      this.destinationPath('images/logo.svg')
    );

    this.fs.copyTpl(
      this.templatePath('src/index.ts'),
      this.destinationPath('src/index.ts'),
      {
        appName: this.appName,
        appTitle: this.appTitle,
        author: "me"
      }
    );

    this.fs.copyTpl(
      this.templatePath('speech-assets/intent-schema.json'),
      this.destinationPath('speech-assets/intent-schema-en_US.json'),
      {
        appName: this.appName,
        appTitle: this.appTitle,
        author: "me"
      }
    );
    this.fs.copyTpl(
      this.templatePath('speech-assets/sample-utterances.txt'),
      this.destinationPath('speech-assets/sample-utterances-en_US.txt'),
      {
        appName: this.appName,
        appTitle: this.appTitle,
        author: "me"
      }
    );

    this.fs.copyTpl(
      this.templatePath('docs/publish-checklist.txt'),
      this.destinationPath('docs/publish-checklist-en_US.txt'),
      {
        appName: this.appName,
        appTitle: this.appTitle,
        author: "me"
      }
    );

    this.fs.copyTpl(
      this.templatePath('package.json'),
      this.destinationPath('package.json'),
      {
        appName: this.appName,
        appTitle: this.appTitle,
        author: "me"
      }
    );
    this.fs.copyTpl(
      this.templatePath('bower.json'),
      this.destinationPath('bower.json'),
      {
        appName: this.appName,
        appTitle: this.appTitle,
        author: "me"
      }
    );
    this.fs.copyTpl(
      this.templatePath('README.md'),
      this.destinationPath('README.md'),
      {
        appName: this.appName,
        appTitle: this.appTitle,
        author: "me"
      }
    );
    this.fs.copyTpl(
      this.templatePath('LICENSE'),
      this.destinationPath('LICENSE'),
      {
        appName: this.appName,
        appTitle: this.appTitle,
        author: "me"
      }
    );
  }

  install() {
    this.installDependencies();

    // this.npmInstall(['restify'], { 'save': true });
  }
};
